# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/speaker_identification/v1/speaker_identification.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'phonexia/grpc/technologies/speaker_identification/v1/speaker_identification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQphonexia/grpc/technologies/speaker_identification/v1/speaker_identification.proto\x12\x34phonexia.grpc.technologies.speaker_identification.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\x82\x01\n\x0e\x43ompareRequest\x12\x37\n\rvoiceprints_a\x18\x01 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\x12\x37\n\rvoiceprints_b\x18\x02 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\"?\n\x0f\x43ompareResponse\x12,\n\x06scores\x18\x01 \x01(\x0b\x32\x1c.phonexia.grpc.common.Matrix\"\x91\x01\n\x0e\x45xtractRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12S\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x43.phonexia.grpc.technologies.speaker_identification.v1.ExtractConfig\"A\n\rExtractConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"w\n\rExtractResult\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\nvoiceprint\x18\x02 \x01(\x0b\x32 .phonexia.grpc.common.Voiceprint\"\xa1\x01\n\x0f\x45xtractResponse\x12S\n\x06result\x18\x01 \x01(\x0b\x32\x43.phonexia.grpc.technologies.speaker_identification.v1.ExtractResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xb3\x01\n\x14VoiceprintComparison\x12\x9a\x01\n\x07\x43ompare\x12\x44.phonexia.grpc.technologies.speaker_identification.v1.CompareRequest\x1a\x45.phonexia.grpc.technologies.speaker_identification.v1.CompareResponse(\x01\x30\x01\x32\xb1\x01\n\x14VoiceprintExtraction\x12\x98\x01\n\x07\x45xtract\x12\x44.phonexia.grpc.technologies.speaker_identification.v1.ExtractRequest\x1a\x45.phonexia.grpc.technologies.speaker_identification.v1.ExtractResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.speaker_identification.v1.speaker_identification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_COMPAREREQUEST']._serialized_start=205
  _globals['_COMPAREREQUEST']._serialized_end=335
  _globals['_COMPARERESPONSE']._serialized_start=337
  _globals['_COMPARERESPONSE']._serialized_end=400
  _globals['_EXTRACTREQUEST']._serialized_start=403
  _globals['_EXTRACTREQUEST']._serialized_end=548
  _globals['_EXTRACTCONFIG']._serialized_start=550
  _globals['_EXTRACTCONFIG']._serialized_end=615
  _globals['_EXTRACTRESULT']._serialized_start=617
  _globals['_EXTRACTRESULT']._serialized_end=736
  _globals['_EXTRACTRESPONSE']._serialized_start=739
  _globals['_EXTRACTRESPONSE']._serialized_end=900
  _globals['_VOICEPRINTCOMPARISON']._serialized_start=903
  _globals['_VOICEPRINTCOMPARISON']._serialized_end=1082
  _globals['_VOICEPRINTEXTRACTION']._serialized_start=1085
  _globals['_VOICEPRINTEXTRACTION']._serialized_end=1262
# @@protoc_insertion_point(module_scope)
