# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/language_identification/v1/language_identification.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'phonexia/grpc/technologies/language_identification/v1/language_identification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSphonexia/grpc/technologies/language_identification/v1/language_identification.proto\x12\x35phonexia.grpc.technologies.language_identification.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\x94\x01\n\x0fIdentifyRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12U\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x45.phonexia.grpc.technologies.language_identification.v1.IdentifyConfig\"\xb2\x01\n\x10IdentifyResponse\x12\x63\n\x06result\x18\x01 \x01(\x0b\x32S.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x1f\n\x1dListSupportedLanguagesRequest\"=\n\x1eListSupportedLanguagesResponse\x12\x1b\n\x13supported_languages\x18\x01 \x03(\t\"\xec\x01\n\x0eIdentifyConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12R\n\tlanguages\x18\x02 \x03(\x0b\x32?.phonexia.grpc.technologies.language_identification.v1.Language\x12T\n\x06groups\x18\x03 \x03(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.LanguageGroup\"!\n\x08Language\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\";\n\rLanguageGroup\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x16\n\x0elanguage_codes\x18\x02 \x03(\t\"\xb4\x01\n\x1cLanguageIdentificationResult\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x62\n\x06scores\x18\x02 \x03(\x0b\x32R.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore\"\xd4\x02\n\x1bLanguageIdentificationScore\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\x12\x65\n\tlanguages\x18\x03 \x03(\x0b\x32R.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore\x12z\n\x0fidentifier_type\x18\x04 \x01(\x0e\x32\x61.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore.IdentifierType\")\n\x0eIdentifierType\x12\x0c\n\x08LANGUAGE\x10\x00\x12\t\n\x05GROUP\x10\x01\x32\x80\x03\n\x16LanguageIdentification\x12\x9d\x01\n\x08Identify\x12\x46.phonexia.grpc.technologies.language_identification.v1.IdentifyRequest\x1aG.phonexia.grpc.technologies.language_identification.v1.IdentifyResponse(\x01\x12\xc5\x01\n\x16ListSupportedLanguages\x12T.phonexia.grpc.technologies.language_identification.v1.ListSupportedLanguagesRequest\x1aU.phonexia.grpc.technologies.language_identification.v1.ListSupportedLanguagesResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.language_identification.v1.language_identification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IDENTIFYREQUEST']._serialized_start=208
  _globals['_IDENTIFYREQUEST']._serialized_end=356
  _globals['_IDENTIFYRESPONSE']._serialized_start=359
  _globals['_IDENTIFYRESPONSE']._serialized_end=537
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_start=539
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_end=570
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_start=572
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_end=633
  _globals['_IDENTIFYCONFIG']._serialized_start=636
  _globals['_IDENTIFYCONFIG']._serialized_end=872
  _globals['_LANGUAGE']._serialized_start=874
  _globals['_LANGUAGE']._serialized_end=907
  _globals['_LANGUAGEGROUP']._serialized_start=909
  _globals['_LANGUAGEGROUP']._serialized_end=968
  _globals['_LANGUAGEIDENTIFICATIONRESULT']._serialized_start=971
  _globals['_LANGUAGEIDENTIFICATIONRESULT']._serialized_end=1151
  _globals['_LANGUAGEIDENTIFICATIONSCORE']._serialized_start=1154
  _globals['_LANGUAGEIDENTIFICATIONSCORE']._serialized_end=1494
  _globals['_LANGUAGEIDENTIFICATIONSCORE_IDENTIFIERTYPE']._serialized_start=1453
  _globals['_LANGUAGEIDENTIFICATIONSCORE_IDENTIFIERTYPE']._serialized_end=1494
  _globals['_LANGUAGEIDENTIFICATION']._serialized_start=1497
  _globals['_LANGUAGEIDENTIFICATION']._serialized_end=1881
# @@protoc_insertion_point(module_scope)
